# Kuzu WebAssembly Example

This example demonstrates how to use Kuzu WebAssembly in a web browser with the persistent IDBFS filesystem.

The first run of the example will create a new database and load some data into it. The second run will query the database and display the results.

After running the example for the first time, you can refresh the page to see the query results.

The output of the queries will be displayed below:

``